part of 'blocs.dart';

abstract class BaseEvent {
  /// Defined ID for this event, will be used for handle event & state
  final String? _tag;

  const BaseEvent({String? tag}) : this._tag = tag;

  String get tag => _tag ?? runtimeType.toString();

  /// Override this getter if this event need connect to remote data source
  bool get needCheckConnection => false;
}

class ResetBlocEvent extends BaseEvent {}

class CancelRunningTaskEvent extends BaseEvent {}

class BasePagingEvent<Q> extends BaseEvent {
  final Q? queryData;
  final int limit;
  final bool isFirstRequest;

  const BasePagingEvent({
    String? tag,
    this.queryData,
    this.limit = defaultLimitPaging,
    this.isFirstRequest = false,
  }) : super(tag: tag);
}

class BaseErrorEvent extends BaseEvent {
  final KntException exception;

  const BaseErrorEvent({
    String? tag,
    required this.exception,
  }) : super(tag: tag);
}
