part of 'blocs.dart';

abstract class BaseState {
  /// Defined ID for this state, will be used for handle event & state
  final String? _tag;

  const BaseState({String? tag}) : this._tag = tag;

  String get tag => _tag ?? runtimeType.toString();
}

class BaseInitState extends BaseState {
  const BaseInitState({String? tag}) : super(tag: tag);
}

class BaseLoadingState extends BaseState {
  const BaseLoadingState({String? tag}) : super(tag: tag);
}

class BaseEmptyResultState extends BaseState {
  const BaseEmptyResultState({String? tag}) : super(tag: tag);
}

class BaseHasResultState<D> extends BaseState {
  final D data;

  const BaseHasResultState(
    this.data, {
    String? tag,
  }) : super(tag: tag);

  @override
  String toString() => '$runtimeType { tag: $tag, data: ${data?.toString()} }';
}

class BasePagingResultState<D> extends BaseHasResultState<List<D>> {
  final int currentOffset;

  const BasePagingResultState(
    List<D> dataList,
    this.currentOffset, {
    String? tag,
  }) : super(dataList, tag: tag);
}

class BaseErrorState extends BaseState {
  final KntException exception;

  const BaseErrorState({
    String? tag,
    required this.exception,
  }) : super(tag: tag);

  @override
  String toString() => '$runtimeType { tag: $tag, exception: $exception }';
}
