class KntException implements Exception {
  final KntIssue? _issue;
  final String? additionalInfo;

  const KntException(
    this._issue, {
    this.additionalInfo,
  });

  KntIssue get issue => _issue ?? KntIssue.undefined;

  @override
  String toString() =>
      '$issue${additionalInfo != null ? '\nAdditional info $additionalInfo' : ''}';
}

/// Should create an extension for error message with switch-case
enum KntIssue {
  undefined,
  parsing,
  noInternet,
  unauthorized,
  hostNotFound,
  serverError,
}

extension HttpCodeExt on int {
  KntIssue get convertedIssue {
    if (this == 401) {
      return KntIssue.unauthorized;
    }
    if (this == 404) {
      return KntIssue.hostNotFound;
    }
    if (this > 400) {
      return KntIssue.serverError;
    }
    return KntIssue.undefined;
  }
}
